pub enum Error {
InvalidInput,
Io,
Timeout,
ConnectionClosed,
InvalidResponse,
}Expand description
General categories of error that can occur during any phase of an HTTP connection.
Variants
InvalidInput
A function argument or field value wasn’t populated, or contained an invalid value, or user- supplied code caused an error.
Io
An underlying I/O error occurred that prevented a connection from being established, a request from being sent, or a response from being read.
Timeout
A timeout expired while waiting for the server to respond, or the client (us) didn’t send request headers within the timeframe the server expected.
ConnectionClosed
The connection is no longer usable for some (probably unexpected) reason.
InvalidResponse
An invalid status code or HTTP 2 message where HTTP 1 was expected.