Module http1

Module http1 

HTTP/1.1 client implementation, utilities to establish an HTTP/1.1 connection over TCP or TLS, and utilities to parse HTTP/1.1 requests.

Structs

Http1
An HTTP/1.1 client that can connect to a server and send HTTP requests/receive HTTP responses. Supports the HTTP/1.1 protocol upgrade mechanism.

Functions

connect
Establish a connection to an HTTP/1.1 server over an existing connection.
connect_tcp
Establish an HTTP/1.1 connection to the server at the given url over plaintext TCP.
connect_tls
Establish an HTTP/1.1 connection to the server at the given url over encrypted TLS.
parse_request
Parses the given byte slice into an HTTP/1.1 request with a String body, or returns an error.