Module http2

Module http2 

HTTP/2 client implementation, and utilities to establish an HTTP/2 connection over TCP or TLS.

Structs

Http2
An HTTP/2 client that can connect to a server and send HTTP requests/receive HTTP responses.

Functions

connect
Establish a connection to an HTTP/2 server over an existing connection.
connect_tcp
Establish an HTTP/2 connection to the server at the given url over plaintext TCP.
connect_tls
Establish an HTTP/2 connection to the server at the given url over encrypted TLS.